@@ -49,9 +49,17 @@ typedef enum
 	ODS_ERROR_NOT_STARTED,
 	ODS_ERROR_TRANSPORT_NOT_AVAILABLE,
 	ODS_ERROR_CONNECTION_REFUSED,
+	ODS_ERROR_CONNECTION_TIMEOUT,
 	ODS_ERROR_BAD_REQUEST,
 	ODS_ERROR_NOT_IMPLEMENTED,
-	ODS_ERROR_SERVER_ERROR
+	ODS_ERROR_SERVER_ERROR,
+	ODS_ERROR_TIMEOUT,
+	ODS_ERROR_CANCELLED,
+	ODS_ERROR_NOT_MODIFIED,
+	ODS_ERROR_DATABASE_ERROR,
+	ODS_ERROR_CONFLICT,
+	ODS_ERROR_UNSUPPORTED_MEDIA_TYPE,
+	ODS_ERROR_NO_FIFO_READER
 } OdsError;
 
 
