@@ -24,6 +24,7 @@
 #include <errno.h>
 #include <locale.h>
 #include <signal.h>
+#include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <glib.h>
@@ -99,28 +100,40 @@ main (int argc, char *argv[])
 	GError *error = NULL;
 	GOptionContext *context;
 	gboolean system_bus = FALSE;
+	gboolean show_version = FALSE;
 	struct sigaction sa;
 
 	const GOptionEntry options[] = {
-		{ "no-daemon", '\0', 0, G_OPTION_ARG_NONE, &no_daemon,
+		{ "no-daemon", 'n', 0, G_OPTION_ARG_NONE, &no_daemon,
 		  "Do not daemonize", NULL },
-		{ "system-bus", '\0', 0, G_OPTION_ARG_NONE, &system_bus,
+		{ "system-bus", 's', 0, G_OPTION_ARG_NONE, &system_bus,
 		  "Use system bus instead of the default session bus", NULL},
+		{ "version", 'v', 0, G_OPTION_ARG_NONE, &show_version,
+		  "Show version of obex-data-server and exit immediately", NULL},
 		{ NULL}
 	};
 
 	setlocale (LC_ALL, "");
 	
+#if defined(USE_IMAGEMAGICK) || defined (USE_GDKPIXBUF)
+	/* threading is only used for BIP stuff */
+	g_thread_init (NULL);
+#endif
+	
 	context = g_option_context_new ("");
-
 	g_option_context_add_main_entries (context, options, NULL);
-
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
 		g_warning ("%s", error->message);
 		g_clear_error (&error);
 	}
+	g_option_context_free (context);
 	
 	g_type_init ();
+	
+	if (show_version) {
+		printf (PACKAGE_STRING "\n");
+		return 0;
+	}
 
 	if (!no_daemon && daemon (0, 0)) {
 		g_warning ("Could not daemonize: %s", g_strerror (errno));
@@ -161,6 +174,7 @@ main (int argc, char *argv[])
 	manager = ods_manager_new ();
 	if (!ods_manager_is_initialized (manager)) {
 		g_warning ("Failed to initialize OdsManager object");
+		g_object_unref (manager);
 		return -1;
 	}
 	
@@ -173,9 +187,6 @@ main (int argc, char *argv[])
 	
 	g_main_loop_run (main_loop);
 	g_object_unref (manager);
-	/*
-	g_option_context_free (context);
-	*/
 
 	return 0;
 }
