@@ -27,16 +27,6 @@
 
 G_BEGIN_DECLS
 
-#define	ODS_SERVER_SESSION_DBUS_PATH_PATTERN	"/org/openobex/serversession%d"
-#define ODS_SERVER_SESSION_DBUS_PATH_MAX_LENGTH	37
-#define	ODS_SERVER_SESSION_DBUS_INTERFACE		"org.openobex.ServerSession"
-
-typedef enum {
-	ODS_SERVER_SESSION_STATE_NOT_CONNECTED,
-	ODS_SERVER_SESSION_STATE_OPEN,
-	ODS_SERVER_SESSION_STATE_BUSY
-} OdsServerSessionState;
-
 #define ODS_TYPE_SERVER_SESSION			(ods_server_session_get_type ())
 #define ODS_SERVER_SESSION(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), ODS_TYPE_SERVER_SESSION, OdsServerSession))
 #define ODS_SERVER_SESSION_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), ODS_TYPE_SERVER_SESSION, OdsServerSessionClass))
@@ -50,6 +40,7 @@ enum {
   ODS_SERVER_SESSION_PATH,
   ODS_SERVER_SESSION_ALLOW_WRITE,
   ODS_SERVER_SESSION_AUTO_ACCEPT,
+  ODS_SERVER_SESSION_REQUIRE_IMAGING_THUMBNAILS,
   ODS_SERVER_SESSION_OWNER,
   ODS_SERVER_SESSION_DBUS_PATH
 };
@@ -77,6 +68,8 @@ typedef struct
 	void		(* error_occurred)		(OdsServerSession *server_session,
 											const gchar *error_name,
 											const gchar *error_message);
+	void		(* remote_display_requested) (OdsServerSession *server_session,
+											const gchar *filename);
 	DBusGConnection *connection;
 } OdsServerSessionClass;
 
@@ -87,6 +80,7 @@ OdsServerSession	*ods_server_session_new			(gint fd,
 														const gchar *path,
 														gboolean allow_write,
 														gboolean auto_accept,
+														gboolean require_imaging_thumbnails,
 														const gchar *owner);
 gboolean	 		 ods_server_session_accept		(OdsServerSession *server_session,
 														DBusGMethodInvocation *context);
@@ -96,7 +90,7 @@ void				 ods_server_session_disconnect_internal (OdsServerSession *server_sessio
 gboolean			 ods_server_session_disconnect	(OdsServerSession *server_session,
 														DBusGMethodInvocation *context);
 GHashTable			*ods_server_session_get_transfer_info	(OdsServerSession *server_session);
-gint				 ods_server_session_cancel_internal (OdsServerSession *server_session);
+gboolean			 ods_server_session_cancel_internal (OdsServerSession *server_session);
 gboolean			 ods_server_session_cancel		(OdsServerSession *server_session,
 														DBusGMethodInvocation *context);
 
