@@ -88,7 +88,12 @@ gboolean	 ods_server_close			(OdsServer *server,
 											DBusGMethodInvocation *context);
 void		 ods_server_dispose			(OdsServer *server);
 gboolean	 ods_server_is_started		(OdsServer *server);
+gboolean	 ods_server_set_option		(OdsServer *server,
+											const gchar *name,
+											GValue *value,
+											DBusGMethodInvocation *context);
 GHashTable	*ods_server_get_server_session_info (OdsServer *server, gchar *session_object);
+gchar		**ods_server_get_server_session_list (OdsServer *server);
 
 G_END_DECLS
 
