@@ -36,30 +36,18 @@
 GMainLoop *loop;
 gint total_bytes_global = -1;
 const gchar* filename;
+DBusGProxy *session_proxy;
 
 static void
-session_created_cb (DBusGProxy *proxy, const char *session_object, gpointer user_data)
-{
-	g_message ("Session object created: %s", session_object);
-}
-
-static void
-session_removed_cb (DBusGProxy *proxy, const char *session_object, gpointer user_data)
-{
-	g_message ("Session removed: %s", session_object);
-	g_main_loop_quit (loop);
-}
-
-static void
-session_connected_cb (DBusGProxy *proxy, gpointer user_data)
+session_connected_cb (DBusGProxy *proxy, const char *session_object, gpointer user_data)
 {
 	gboolean	ret;
 	GError		*error = NULL;
 	//gchar		*listing;
-	
-	g_message ("Session connected");
+		
+	g_message ("Session connected: %s", session_object);
 	/*g_message ("RetrieveFolderListing ()");
-	ret = dbus_g_proxy_call (proxy, "RetrieveFolderListing", &error, 
+	ret = dbus_g_proxy_call (session_proxy, "RetrieveFolderListing", &error, 
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -72,7 +60,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 	
 	g_message ("GetCurrentPath ()");
-	ret = dbus_g_proxy_call (proxy, "GetCurrentPath", &error,
+	ret = dbus_g_proxy_call (session_proxy, "GetCurrentPath", &error,
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -85,7 +73,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}*/
 	
 	/*g_message ("ChangeCurrentFolder (\"Data\")");
-	ret = dbus_g_proxy_call (proxy, "ChangeCurrentFolder", &error,
+	ret = dbus_g_proxy_call (session_proxy, "ChangeCurrentFolder", &error,
 								G_TYPE_STRING, "Data",
 								G_TYPE_INVALID,
 								G_TYPE_INVALID);
@@ -95,7 +83,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 	
 	g_message ("GetCurrentPath ()");
-	ret = dbus_g_proxy_call (proxy, "GetCurrentPath", &error,
+	ret = dbus_g_proxy_call (session_proxy, "GetCurrentPath", &error,
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -108,7 +96,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 	
 	g_message ("RetrieveFolderListing ()");
-	ret = dbus_g_proxy_call (proxy, "RetrieveFolderListing", &error, 
+	ret = dbus_g_proxy_call (session_proxy, "RetrieveFolderListing", &error, 
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -125,7 +113,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	
 	
 	g_message ("ChangeCurrentFolder (\"../Pictures\")");
-	ret = dbus_g_proxy_call (proxy, "ChangeCurrentFolder", &error,
+	ret = dbus_g_proxy_call (session_proxy, "ChangeCurrentFolder", &error,
 								G_TYPE_STRING, "../Pictures",
 								G_TYPE_INVALID,
 								G_TYPE_INVALID);
@@ -136,7 +124,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 	
 	g_message ("GetCurrentPath ()");
-	ret = dbus_g_proxy_call (proxy, "GetCurrentPath", &error,
+	ret = dbus_g_proxy_call (session_proxy, "GetCurrentPath", &error,
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -149,7 +137,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 	
 	g_message ("RetrieveFolderListing ()");
-	ret = dbus_g_proxy_call (proxy, "RetrieveFolderListing", &error, 
+	ret = dbus_g_proxy_call (session_proxy, "RetrieveFolderListing", &error, 
 								G_TYPE_INVALID,
 								G_TYPE_STRING, &listing,
 								G_TYPE_INVALID);
@@ -162,7 +150,7 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}*/
 	
 	/*g_message ("CopyRemoteFile (\"060820_143442.jpg\", \"/home/skirsdeda/Desktop/x.jpg\")");
-	ret = dbus_g_proxy_call (proxy, "CopyRemoteFile", &error,
+	ret = dbus_g_proxy_call (session_proxy, "CopyRemoteFile", &error,
 								G_TYPE_STRING, "060820_143442.jpg",
 								G_TYPE_STRING, "/home/skirsdeda/Desktop/x.jpg",
 								G_TYPE_INVALID,
@@ -172,8 +160,36 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 		g_clear_error (&error);
 	}*/
 	
+	/*gchar *capabilities;
+	g_message ("GetImagingCapabilities ()");
+	ret = dbus_g_proxy_call (session_proxy, "GetImagingCapabilities", &error,
+								G_TYPE_INVALID,
+								G_TYPE_STRING, &capabilities,
+								G_TYPE_INVALID);
+	if (!ret) {
+		g_warning ("Error: %s", error->message);
+		g_clear_error (&error);
+	} else {
+		g_message ("Imaging capabilities:\n%s", capabilities);
+		g_free (capabilities);
+	}*/
+	
+	/*ret = dbus_g_proxy_call (session_proxy, "SetTransferHints", &error,
+								G_TYPE_STRING, "blah",
+								G_TYPE_STRING, "",
+								G_TYPE_STRING, "",
+								G_TYPE_UINT64, (guint64)0,
+								G_TYPE_INT64, (gint64)-1,
+								G_TYPE_INT64, (gint64)-1,
+								G_TYPE_INVALID,
+								G_TYPE_INVALID);
+	if (!ret) {
+		g_warning ("Error: %s", error->message);
+		g_clear_error (&error);
+	}*/
+	
 	g_message ("SendFile (\"%s\")", filename);
-	ret = dbus_g_proxy_call (proxy, "SendFile", &error,
+	ret = dbus_g_proxy_call (session_proxy, "SendFile", &error,
 								G_TYPE_STRING, filename,
 								G_TYPE_INVALID,
 								G_TYPE_INVALID);
@@ -183,6 +199,21 @@ session_connected_cb (DBusGProxy *proxy, gpointer user_data)
 	}
 }
 
+static void
+session_connect_error_cb (DBusGProxy *proxy, const char *session_object,
+							const char *error_name, const char *error_message,
+							gpointer user_data)
+{
+	g_message ("Session connect error: %s: %s", error_name, error_message);
+}
+
+static void
+session_closed_cb (DBusGProxy *proxy, const char *session_object, gpointer user_data)
+{
+	g_message ("Session removed: %s", session_object);
+	g_main_loop_quit (loop);
+}
+
 static void
 transfer_started_cb (DBusGProxy *proxy, const char *filename,
 						const char *local_path, guint64 total_bytes,
@@ -374,12 +405,13 @@ create_bluetooth_session (DBusGConnection *dbus_connection,
 {
 	int ret;
 	gchar *session_object_path = NULL;
-	DBusGProxy *session_proxy;
 	GError *error = NULL;
 
-	g_message ("CreateBluetoothSession (\"%s\", \"%s\")", address, pattern);	
+	g_message ("CreateBluetoothSession (\"%s\", \"00:00:00:00:00:00\", \"%s\")",
+				address, pattern);	
 	ret = dbus_g_proxy_call (dbus_proxy, "CreateBluetoothSession", &error, 
 							G_TYPE_STRING, address,
+							G_TYPE_STRING, "00:00:00:00:00:00",
 							G_TYPE_STRING, pattern,
 							G_TYPE_INVALID,
 							DBUS_TYPE_G_OBJECT_PATH, &session_object_path,
@@ -411,9 +443,6 @@ create_bluetooth_session (DBusGConnection *dbus_connection,
 											G_TYPE_STRING,
 											G_TYPE_INVALID);
 		
-		dbus_g_proxy_add_signal (session_proxy, "Connected", G_TYPE_INVALID);
-		dbus_g_proxy_connect_signal (session_proxy, "Connected", G_CALLBACK (session_connected_cb),
-				       NULL, NULL);
 		dbus_g_proxy_add_signal (session_proxy, "Disconnected", G_TYPE_INVALID);
 		dbus_g_proxy_connect_signal (session_proxy, "Disconnected", G_CALLBACK (session_disconnected_cb),
 				       NULL, NULL);
@@ -429,6 +458,9 @@ create_bluetooth_session (DBusGConnection *dbus_connection,
 		dbus_g_proxy_add_signal (session_proxy, "ErrorOccurred", G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
 		dbus_g_proxy_connect_signal (session_proxy, "ErrorOccurred", G_CALLBACK (error_occurred_cb),
 						NULL, NULL);
+		/*dbus_g_proxy_call (dbus_proxy, "CancelSessionConnect", &error,
+									G_TYPE_STRING, session_object_path,
+									G_TYPE_INVALID, G_TYPE_INVALID);*/
 		if (session_object_path != NULL)
 			g_free (session_object_path);
 		return TRUE;
@@ -466,12 +498,24 @@ main (int argc, char *argv[])
 	dbus_proxy = dbus_g_proxy_new_for_name (dbus_connection, "org.openobex",
 											 "/org/openobex", 
 											 "org.openobex.Manager");
-	dbus_g_proxy_add_signal (dbus_proxy, "SessionCreated", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (dbus_proxy, "SessionCreated", G_CALLBACK (session_created_cb),
-			       NULL, NULL);
-	dbus_g_proxy_add_signal (dbus_proxy, "SessionRemoved", DBUS_TYPE_G_OBJECT_PATH, G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (dbus_proxy, "SessionRemoved", G_CALLBACK (session_removed_cb),
-			       NULL, NULL);
+	dbus_g_object_register_marshaller (ods_marshal_VOID__STRING_STRING_STRING,
+												G_TYPE_NONE,
+												DBUS_TYPE_G_OBJECT_PATH,
+												G_TYPE_STRING,
+												G_TYPE_STRING,
+												G_TYPE_INVALID);
+	dbus_g_proxy_add_signal (dbus_proxy, "SessionConnected",
+					DBUS_TYPE_G_OBJECT_PATH, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (dbus_proxy, "SessionConnected",
+					G_CALLBACK (session_connected_cb), NULL, NULL);
+	dbus_g_proxy_add_signal (dbus_proxy, "SessionConnectError",
+					DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (dbus_proxy, "SessionConnectError",
+					G_CALLBACK (session_connect_error_cb), NULL, NULL);
+	dbus_g_proxy_add_signal (dbus_proxy, "SessionClosed", 
+					DBUS_TYPE_G_OBJECT_PATH, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (dbus_proxy, "SessionClosed",
+					G_CALLBACK (session_closed_cb), NULL, NULL);
 	
 	if (!create_bluetooth_session (dbus_connection, dbus_proxy, argv[1], argv[2]))
 	    return 1;
